import { LocalizedVenueMedia } from './utils/cms';

interface IVenueId {
    venue: string;
}
export interface ITimeRange {
    from: string;
    to: string;
}
export interface IWeek {
    MON?: ITimeRange[];
    TUE?: ITimeRange[];
    WED?: ITimeRange[];
    THU?: ITimeRange[];
    FRI?: ITimeRange[];
    SAT?: ITimeRange[];
    SUN?: ITimeRange[];
}
export declare function useCms<T>(id: string, intervalSeconds?: number, withLocalStorage?: boolean, baseUrl?: string, tenant?: string): {
    value: T | null;
    isError: boolean;
    isLoading: boolean;
    refresh: (abortSignal?: AbortSignal) => Promise<boolean | undefined>;
};
export declare function useCmsInConfigContext<T>({ id, intervalSeconds, withLocalStorage, }: {
    id: string;
    intervalSeconds?: number;
    withLocalStorage?: boolean;
}): {
    value: T | null;
    isError: boolean;
    isLoading: boolean;
    refresh: (abortSignal?: AbortSignal | undefined) => Promise<boolean | undefined>;
};
export declare function useVenueCms<T extends IVenueId>(id: string, intervalSeconds?: number, withLocalStorage?: boolean, baseUrl?: string, tenant?: string, venue?: string): {
    value: T | null;
    isError: boolean;
    refresh: (abortSignal?: AbortSignal | undefined) => Promise<boolean | undefined>;
};
export declare function useLocalizedVenueMedia(id: string, venue: string, locale: string, intervalSeconds?: number, withLocalStorage?: boolean): {
    isError?: boolean;
    url: string | string[] | null;
    fallbackUrl: string | string[] | null;
    mediaType?: LocalizedVenueMedia['mediaType'];
};
export declare function useLocalizedVenueMediaLegacy(id: string, venue: string, locale: string, intervalSeconds?: number, withLocalStorage?: boolean, baseUrl?: string, tenant?: string): {
    isError?: boolean;
    url: string | string[] | null;
    fallbackUrl: string | string[] | null;
    mediaType?: LocalizedVenueMedia['mediaType'];
    refresh: ReturnType<typeof useCms>['refresh'];
};
interface KioskMedia {
    introScreen: LocalizedVenueMedia[];
    orderStartScreen: LocalizedVenueMedia[];
    inactiveScreen: LocalizedVenueMedia[];
    disabledScreen: LocalizedVenueMedia[];
}
export declare function useKioskMediaCms({ kioskMediaId, kioskMediaType, intervalSeconds, withLocalStorage, baseUrl, tenant, venue, locale, }: {
    kioskMediaId: string;
    kioskMediaType: keyof KioskMedia;
    intervalSeconds?: number;
    withLocalStorage?: boolean;
    baseUrl: string;
    tenant: string;
    venue: string;
    locale: string;
    imageDisplayTime?: number;
}): {
    url: string | string[] | null;
    fallbackUrl: string | string[] | null;
    mediaType: "IMAGE" | "VIDEO" | undefined;
    isError: boolean;
    isLoading: boolean;
    imageDisplayTime: number | undefined;
    refresh: (abortSignal?: AbortSignal | undefined) => Promise<boolean | undefined>;
};
export declare function useKioskMediaCmsWithContext({ kioskMediaId, kioskMediaType, venue, language, intervalSeconds, withLocalStorage, }: {
    kioskMediaId: string;
    kioskMediaType: keyof KioskMedia;
    venue: string;
    language: string;
    intervalSeconds?: number;
    withLocalStorage?: boolean;
}): {
    url: string | string[] | null;
    fallbackUrl: string | string[] | null;
    mediaType: "IMAGE" | "VIDEO" | undefined;
    isError: boolean;
    isLoading: boolean;
    imageDisplayTime: number | undefined;
    refresh: (abortSignal?: AbortSignal | undefined) => Promise<boolean | undefined>;
};
export {};
//# sourceMappingURL=useCms.d.ts.map